@@ -125,14 +125,63 @@ def likelihood_scan(**kwargs):
     from quickstats.components.likelihood import scan_nll
     scan_nll(**kwargs)
 
+@click.command(name='cls_limit')
+@click.option('-i', '--input_file', 'filename', required=True, help='Path to the input workspace file')
+@click.option('-p', '--poi', 'poi_name', default=None, help='POI to scan. If not specified, the first POI from the workspace is used.')
+@click.option('-d', '--data', 'data_name', default='combData', help='Name of dataset')
+@click.option('-o', '--outname', default='limits.json', help='Name of output')
+@click.option('--blind/--unblind', 'do_blind', default=True, help='Blind/unblind analysis')
+@click.option('--CL', 'CL', default=0.95, help='CL value to use')
+@click.option('--precision', default=0.005, help='precision in mu that defines iterative cutoff')
+@click.option('--do_tilde/--no_tilde', default=True, help='bound mu at zero if true and do the \tilde{q}_{mu} asymptotics')
+@click.option('--do_better_bands/--skip_better_bands', default=True, help='evaluate asymptotic CLs limit for various sigma bands')
+@click.option('--better_negative_bands/--skip_better_negative_bands', default=False, 
+              help='evaluate asymptotic CLs limit for negative sigma bands')
+@click.option('--binned/--unbinned', 'binned_likelihood', default=True, help='Binned likelihood')
+@click.option('--save_summary/--skip_summary', default=True, help='Save summary information')
+@click.option('-f', '--fix', default="", help='Parameters to fix')
+@click.option('-r', '--profile', default="", help='Parameters to profile')
+@click.option('-w', '--workspace', 'ws_name', default=None, help='Name of workspace. Auto-detect by default.')
+@click.option('-m', '--model_config', 'mc_name', default=None, help='Name of model config. Auto-detect by default.')
+@click.option('-s', '--snapshot', 'snapshot_name', default=None, help='Name of initial snapshot')
+@click.option('-t', '--minimizer_type', default="Minuit2", help='Minimizer type')
+@click.option('-a', '--minimizer_algo', default="Migrad", help='Minimizer algorithm')
+@click.option('-e', '--eps', type=float, default=1.0, help='Convergence criterium')
+@click.option('--strategy', type=int, default=0, help='Default minimization strategy')
+@click.option('--print_level', type=int, default=-1, help='Minimizer print level')
+@click.option('--timer/--no_timer', default=False, help='Enable minimizer timer')
+@click.option('-c', '--num_cpu', type=int, default=1, help='Number of CPUs to use per parameter')
+@click.option('--offset/--no-offset', default=True, help='Offset likelihood')
+@click.option('--optimize/--no-optimize', default=True, help='Optimize constant terms')
+@click.option('--fix-cache/--no-fix-cache', default=True, help='Fix StarMomentMorph cache')
+@click.option('--fix-multi/--no-fix-cache',  default=True, help='Fix MultiPdf level 2')
+@click.option('--max_calls', type=int, default=-1, help='Maximum number of function calls')
+@click.option('--max_iters', type=int, default=-1, help='Maximum number of Minuit iterations')
+@click.option('--constrain/--no-constrain', 'constrain_nuis', default=True, help='Use constrained NLL')
+def cls_limit(**kwargs):
+    """
+    Tool for evaluating Asymptotic CLs limit
+    """
+    from quickstats.components import AsymptoticsCLs
+    outname = kwargs.pop('outname')
+    save_summary = kwargs.pop('save_summary')
+    asymptotic_cls = AsymptoticsCLs(**kwargs)
+    asymptotic_cls.evaluate_limits()
+    asymptotic_cls.save(outname, summary=save_summary)
+
 @click.command(name='compile')
-def compile_macros():
+@click.option('-m', '--macros', default=None, help='Macros to compile (separated by commas)')
+def compile_macros(macros):
     """
     Compile ROOT macros
     """
     from quickstats.utils.root_utils import compile_macro
-    compile_macro("RooTwoSidedCBShape")
-    
+    if macros is None:
+        macros = ["RooTwoSidedCBShape", "AsymptoticCLsTool", "RooDataSetObjects"]
+    else:
+        macros = macros.split(',')
+    for macro in macros:
+        compile_macro(macro)
     
 @click.command(name='harmonize_np')
 @click.argument('ws_files', nargs=-1)
