@@ -132,23 +132,4 @@ def compile_macros():
     """
     from quickstats.utils.root_utils import compile_macro
     compile_macro("RooTwoSidedCBShape")
-    
-    
-@click.command(name='harmonize_np')
-@click.argument('ws_files', nargs=-1)
-@click.option('-r', '--reference', required=True, help='Path to reference json file containing renaming scheme')
-@click.option('-i', '--input_config_path', default=None, help='Path to json file containing input workspace paths')
-@click.option('-b', '--base_path', default='./', help='Base path for input config')
-@click.option('-o', '--outfile', default='renamed_np.json', help='Output filename')
-def harmonize_np(ws_files, reference, input_list, base_path, outfile):
-    """
-    Harmonize NP names across different workspaces
-    """
-    from quickstats.components import NuisanceParameterHarmonizer
-    harmonizer = NuisanceParameterHarmonizer(reference)
-    if (len(ws_files) > 0) and input_list is not None:
-        raise RuntimeError('either workspace paths or json file containing workspace paths should be given')
-    if len(ws_files) > 0:
-        harmonizer.harmonize(ws_files, outfile=outfile)
-    elif (input_list is not None):
-        harmonizer.harmonize_multi_input(input_list, base_path, outfile=outfile)
\ No newline at end of file
+    
\ No newline at end of file
